#version 3.5;

#declare PHOT      = 0;  // photons 0=out; 1=save photons; 2=load photons
#declare Save_Rad  = 0;  // 1=save rad; 2=load rad data; 0=no rad storing
#declare RAD       = 0;  // radiosity quality settings 0=out; 1=acceptable; 5=good
                
global_settings {
        #declare a_g = 1;
        assumed_gamma a_g
        max_trace_level 20
        //noise_generator 2
        #if (PHOT > 0)
                photons {
                        spacing 0.05
                        autostop 0
                        jitter 1
                        #if (PHOT = 1)
                                save_file "pov.ph"
                        #else
                                load_file "pov.ph"
                        #end                        
                }
        #end  
        #if(RAD > 0)
                radiosity {
                        pretrace_start 1
                        pretrace_end   1
                        count 30*RAD                
                        nearest_count 8      
                        error_bound 0.5/RAD      
                        recursion_limit 1      
                        gray_threshold 0  
                        minimum_reuse 0.015 
                        brightness 1      
                        adc_bailout 0.005
                        normal on
                        media on
                        #if (Save_Rad = 1)
                                save_file "pov.rad"
                        #else
                                #if (Save_Rad = 2)
                                        load_file "pov.rad" 
                                        always_sample off
                                #end
                        #end                          
                }
        #end
}        

#if (RAD > 0)
        #default {finish {ambient 0}}
        #declare amb = 0;
#else
        #declare amb = 1;
#end

#declare camlocation = <0,0.5,-10>;
#declare camlookat   = <0,2.2,0>;
#declare lightsource = <42,50,100>;

camera {ultra_wide_angle location camlocation right x*16/9 look_at camlookat angle 85}

light_source {
        camlocation, 
        0.1 
        shadowless
}
light_source {
        lightsource,
        <1,0.836*0.836,0.567*0.567>*2.4 
        area_light <0.5,0,0> <0,0.5,0> 3,3 adaptive 0 jitter circular orient         
        //media_attenuation off
} 

sky_sphere {
        pigment {
                gradient y 
                color_map {
                        [0 rgb <1,0.25,0>]
                        [1 rgb <1,0.6,0.15>]
                }
        }
        translate y*-0.1
}

#include "functions.inc"
#declare foo = function {0}

//_________________________________________________________________________________

#declare V_WorldBoundMin = <-0.231386,-0.007820,-0.245243>;
#declare V_WorldBoundMax = <0.286811,0.167417,0.363223>;

#declare dragonfly_pig = pigment {image_map {png "dragonfly_pigm4" interpolate 2}}
#declare dragonfly_pigT = pigment {image_map {png "dragonfly_pigm4" interpolate 2 transmit all 1}}
#declare dragonfly_norm = normal {bump_map {png "dragonfly_bump" interpolate 2 bump_size 1}}
#declare dragonfly_fin = finish {ambient 0.1 diffuse 3}
#declare dragonfly_finS = finish {ambient 0.1 diffuse 3 specular 2 roughness 0.01 metallic 1}


#declare tex_S0T0 = 
texture {
        pigment {dragonfly_pig}
        normal {dragonfly_norm}
        finish {dragonfly_fin}
}       

#declare tex_S1T0 = 
texture {
        pigment {dragonfly_pig}
        normal {dragonfly_norm}
        finish {dragonfly_finS}
}

#declare tex_S0T1 = 
texture {
        pigment {dragonfly_pigT}
        normal {dragonfly_norm}
        finish {dragonfly_fin}
}       

#declare tex_S1T1 = 
texture {
        pigment {dragonfly_pigT}
        normal {dragonfly_norm}
        finish {dragonfly_finS}
}

#declare ST0 =
texture {
        image_pattern {png "dragonfly_reflec2"} 
        texture_map {
                [0 tex_S0T0]                 
                [1 tex_S1T0] 
        }
}

#declare ST1 =
texture {
        image_pattern {png "dragonfly_reflec2"} 
        texture_map {
                [0 tex_S0T1] 
                [1 tex_S1T1] 
        }
}

#declare dragonfly_tex =
texture {
         image_pattern {png "dragonfly_trans2"} 
         texture_map {
                [0 ST0] 
                [0.9 ST1] 
         }
}

#declare T_eyes =
texture {
        pigment {color rgb <0,0.1,0.2>*0.2}
        finish {
                ambient 0
                diffuse 0.2
                reflection 0.1
                specular 0.2
                roughness 0.03
                //metallic 1
                irid {
                        0.2
                        thickness 0.9
                        turbulence 1
                }                
        }
        normal {crackle 0.7 scale 0.007}        
}





#declare T_wings = texture {dragonfly_tex}
//#declare T_eyes = texture {dragonfly_tex}
#declare T_head = texture {dragonfly_tex}
#declare T_body = texture {dragonfly_tex}

        
#include "dragonfly1_mesh.inc"

#declare full_filter_pigment = pigment // full_filter_pigment
{
	transmit 1.0
}

#declare full_filter_normal = normal // full_filter_normal
{
	bumps, 0 
}

// Material2
#declare cpig_T_Material2 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material2 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material2 = 
texture // Material2
{
	pigment { cpig_T_Material2 } 
	finish  { fin_T_Material2 } 
}

// Material3
#declare cpig_T_Material3 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material3 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material3 = 
texture // Material3
{
	pigment { cpig_T_Material3 } 
	finish  { fin_T_Material3 } 
}

// Material4
#declare cpig_T_Material4 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material4 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material4 = 
texture // Material4
{
	pigment { cpig_T_Material4 } 
	finish  { fin_T_Material4 } 
}

// Material6
#declare cpig_T_Material6 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material6 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material6 = 
texture // Material6
{
	pigment { cpig_T_Material6 } 
	finish  { fin_T_Material6 } 
}

// Material7
#declare cpig_T_Material7 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material7 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material7 = 
texture // Material7
{
	pigment { cpig_T_Material7 } 
	finish  { fin_T_Material7 } 
}

// Material8
#declare cpig_T_Material8 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material8 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material8 = 
texture // Material8
{
	pigment { cpig_T_Material8 } 
	finish  { fin_T_Material8 } 
}

// Material10
#declare cpig_T_Material10 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material10 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material10 = 
texture // Material10
{
	pigment { cpig_T_Material10 } 
	finish  { fin_T_Material10 } 
}

// Material11
#declare cpig_T_Material11 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material11 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material11 = 
texture // Material11
{
	pigment { cpig_T_Material11 } 
	finish  { fin_T_Material11 } 
}

// Material12
#declare cpig_T_Material12 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material12 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material12 = 
texture // Material12
{
	pigment { cpig_T_Material12 } 
	finish  { fin_T_Material12 } 
}

// Material17
#declare cpig_T_Material17 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material17 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material17 = 
texture // Material17
{
	pigment { cpig_T_Material17 } 
	finish  { fin_T_Material17 } 
}

// Material18
#declare cpig_T_Material18 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material18 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material18 = 
texture // Material18
{
	pigment { cpig_T_Material18 } 
	finish  { fin_T_Material18 } 
}

// Material19
#declare cpig_T_Material19 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material19 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material19 = 
texture // Material19
{
	pigment { cpig_T_Material19 } 
	finish  { fin_T_Material19 } 
}

// Material20
#declare cpig_T_Material20 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material20 = 
finish
{
	ambient 1 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material20 = 
texture // Material20
{
	pigment { cpig_T_Material20 } 
	finish  { fin_T_Material20 } 
}

// Material21
#declare cpig_T_Material21 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material21 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material21 = 
texture // Material21
{
	pigment { cpig_T_Material21 } 
	finish  { fin_T_Material21 } 
}

// Material22
#declare cpig_T_Material22 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material22 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material22 = 
texture // Material22
{
	pigment { cpig_T_Material22 } 
	finish  { fin_T_Material22 } 
}

// Material23
#declare cpig_T_Material23 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material23 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material23 = 
texture // Material23
{
	pigment { cpig_T_Material23 } 
	finish  { fin_T_Material23 } 
}

// Material25
#declare cpig_T_Material25 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material25 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material25 = 
texture // Material25
{
	pigment { cpig_T_Material25 } 
	finish  { fin_T_Material25 } 
}

// Material26
#declare cpig_T_Material26 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material26 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material26 = 
texture // Material26
{
	pigment { cpig_T_Material26 } 
	finish  { fin_T_Material26 } 
}

// Material27
#declare cpig_T_Material27 = 
pigment
{
	color rgb <0.16, 0.2, 0.2>
}

#declare fin_T_Material27 = 
finish
{
	ambient 0 
	diffuse 0.3
	phong 1 
	phong_size 15.5
}

#declare T_Material27 = 
texture // Material27
{
	pigment { cpig_T_Material27 } 
	finish  { fin_T_Material27 } 
}

#include "dragonfly2_mesh.inc"

union {
        object{ P_Abdomen }
        object{ P_Head }
        object{ P_righteye }
        object{ P_lefteye }
        object{ P_llwing }
        object{ P_luwing }
        object{ P_rlwing }
        object{ P_ruwing }
        object{ P_tail2 }
        object{ P_tail3 }
        object{ P_tail4 }
        object{ P_tail5 }
        object{ P_tail6 }
        object{ P_tail7 }
        union {
                object{ P_BEIN3_1_LI }
                object{ P_BEIN3_2_LI }
                object{ P_BEIN3_3_LI }
                object{ P_BEIN3_1_RE }
                object{ P_BEIN3_2_RE }
                object{ P_BEIN3_3_RE }
                object{ P_BEIN2_1_RE }
                object{ P_BEIN2_2_RE }
                object{ P_BEIN2_3_RE }
                object{ P_BEIN1_1_RE }
                object{ P_BEIN1_2_RE }
                object{ P_BEIN1_3_RE }
                object{ P_BEIN1_1_LI }
                object{ P_BEIN1_2_LI }
                object{ P_BEIN1_3_LI }
                object{ P_BEIN2_1_LI }
                object{ P_BEIN2_2_LI }
                object{ P_BEIN2_3_LI }
                scale 0.0004
                rotate x*-80
                translate <0,0.109,0.13>
        }
        scale 40
        rotate <208.9,175.6,-113.5>
        translate <6.25,-136.9,115.45>         
        translate y*129
        rotate x*-85
        translate y*37.99614
        scale 0.02
        rotate z*-15
        translate <-1.7,-1.5,-8.5>
}

#include "frosted_plant1.inc"